@@ -1,5 +1,6 @@
 import logging
 
+from health_check.exceptions import ServiceUnavailable
 from health_check.storage.backends import StorageHealthCheck
 
 
@@ -18,7 +19,10 @@ class S3Boto3StorageHealthCheck(StorageHealthCheck):
 
     logger = logging.getLogger(__name__)
     storage = "storages.backends.s3boto3.S3Boto3Storage"
+    storage_alias = "default"
 
     def check_delete(self, file_name):
         storage = self.get_storage()
+        if not storage.exists(file_name):
+            raise ServiceUnavailable("File does not exist")
         storage.delete(file_name)
